@@ -156,6 +156,7 @@ class GbpOptionParser(OptionParser):
                 'pbuilder-options': '',
                 'postbuild': '',
                 'postclone': '',
+                'postedit': '',
                 'postexport': '',
                 'postimport': '',
                 'posttag': '',
@@ -434,12 +435,12 @@ class GbpOptionParser(OptionParser):
         self.config_parser.read(filename)
 
     def _warn_old_config_section(self, oldcmd, cmd):
-        if not os.getenv("GBP_DISABLE_SECTION_DEPRECTATION"):
+        if not os.getenv("GBP_DISABLE_SECTION_DEPRECATION"):
             gbp.log.warn("Old style config section [%s] found "
                          "please rename to [%s]" % (oldcmd, cmd))
 
     def _warn_old_gbp_conf(self, gbp_conf):
-        if (not os.getenv("GBP_DISABLE_GBP_CONF_DEPRECTATION") and
+        if (not os.getenv("GBP_DISABLE_GBP_CONF_DEPRECATION") and
                 not self._warned_old_gbp_conf):
             gbp.log.warn("Deprecated configuration file found at %s, "
                          "check gbp.conf(5) for alternatives" % gbp_conf)
@@ -558,7 +559,7 @@ class GbpOptionParser(OptionParser):
             to parse
         @type sections: C{list} of C{str}
         """
-        self.command = command
+        self.command = command[:-3] if command.endswith('.py') else command
         self.sections = sections
         self.prefix = prefix
         self.config = {}
@@ -786,6 +787,7 @@ class GbpOptionParserRpm(GbpOptionParser):
         'changelog-revision': '',
         'spawn-editor': 'always',
         'editor-cmd': 'vim',
+        'spec-vcs-tag': '',
     })
 
     help = dict(GbpOptionParser.help)
@@ -847,6 +849,9 @@ class GbpOptionParserRpm(GbpOptionParser):
             'git-author':
                 "Use name and email from git-config for the changelog header, "
                 "default is '%(git-author)s'",
+            'spec-vcs-tag':
+                "Set/update the 'VCS:' tag in the spec file, empty value "
+                "removes the tag entirely, default is '%(spec-vcs-tag)s'",
         })
 
     def _warn_old_gbp_conf(self, gbp_conf):
