@@ -155,6 +155,9 @@ def build_parser(name):
                                         dest="packaging_branch")
     branch_group.add_config_file_option(option_name="upstream-branch",
                                         dest="upstream_branch")
+    branch_group.add_option("--upstream-vcs-tag", dest="vcs_tag",
+                            help="Upstream VCS tag on top of which to import "
+                            "the orig sources")
     branch_group.add_boolean_config_file_option(
         option_name="create-missing-branches",
         dest="create_missing_branches")
@@ -174,6 +177,9 @@ def build_parser(name):
                                      dest="packaging_tag")
     tag_group.add_config_file_option(option_name="upstream-tag",
                                      dest="upstream_tag")
+    tag_group.add_option("--skip-packaging-tag", dest="skip_packaging_tag",
+                         action="store_true",
+                         help="Don't add a tag after importing packaging files")
 
     import_group.add_config_file_option(option_name="filter",
                                         dest="filters", action="append")
@@ -331,23 +337,20 @@ def main(argv):
 
         tag_str_fields = dict(spec.version, vendor=options.vendor.lower())
         if options.native:
-            src_tag_format = options.packaging_tag
-            src_tag = repo.version_to_tag(src_tag_format, tag_str_fields)
-            upstream_tag = src_tag
+            upstream_tag_format = options.packaging_tag
             upstream_str_fields = tag_str_fields
         else:
-            src_tag_format = options.upstream_tag
-            src_tag = repo.version_to_tag(src_tag_format, tag_str_fields)
+            upstream_tag_format = options.upstream_tag
             upstream_str_fields = filter_version(tag_str_fields, 'release', 'epoch')
-            upstream_tag = repo.version_to_tag(src_tag_format, upstream_str_fields)
-
-        ver_str = compose_version_str(spec.version)
+        upstream_tag = repo.version_to_tag(upstream_tag_format, upstream_str_fields)
 
+        full_version = compose_version_str(spec.version)
         if repo.find_version(options.packaging_tag, tag_str_fields):
-            gbp.log.warn("Version %s already imported." % ver_str)
+            gbp.log.warn("Version %s already imported." % full_version)
+
             if options.allow_same_version:
                 gbp.log.info("Moving tag of version '%s' since import forced" %
-                             ver_str)
+                             full_version)
                 move_tag_stamp(repo, options.packaging_tag, tag_str_fields)
             else:
                 raise SkipImport
@@ -370,9 +373,9 @@ def main(argv):
 
         # Import sources
         if sources:
-            src_commit = repo.find_version(src_tag_format, upstream_str_fields)
-            if not src_commit:
-                gbp.log.info("Tag %s not found, importing sources" % src_tag)
+            upstream_commit = repo.find_version(upstream_tag_format, upstream_str_fields)
+            if not upstream_commit:
+                gbp.log.info("Tag %s not found, importing sources" % upstream_tag)
 
                 branch = [options.upstream_branch,
                           options.packaging_branch][options.native]
@@ -384,19 +387,27 @@ def main(argv):
                         gbp.log.err(no_upstream_branch_msg % branch + "\n"
                                     "Also check the --create-missing-branches option.")
                         raise GbpError
-                src_vendor = "Native" if options.native else "Upstream"
-                msg = "%s version %s" % (src_vendor, spec.upstreamversion)
-                src_commit = repo.commit_dir(sources.unpacked,
-                                             "Import %s" % msg,
-                                             branch,
-                                             author=author,
-                                             committer=committer,
-                                             create_missing_branch=options.create_missing_branches)
-                repo.create_tag(name=src_tag if options.native else upstream_tag,
-                                msg=msg,
-                                commit=src_commit,
-                                sign=options.sign_tags,
-                                keyid=options.keyid)
+                upstream_vendor = "Native" if options.native else "Upstream"
+                upstream_version = full_version if options.native else spec.upstreamversion
+                msg = "%s version %s" % (upstream_vendor, upstream_version)
+                if options.vcs_tag:
+                    vcs_tag = repo.version_to_tag(options.vcs_tag, upstream_str_fields)
+                    parents = [repo.rev_parse("%s^{}" % vcs_tag)]
+                else:
+                    parents = None
+                upstream_commit = repo.commit_dir(sources.unpacked,
+                                                  "Import %s" % msg,
+                                                  branch,
+                                                  other_parents=parents,
+                                                  author=author,
+                                                  committer=committer,
+                                                  create_missing_branch=options.create_missing_branches)
+                if not (options.native and options.skip_packaging_tag):
+                    repo.create_tag(name=upstream_tag,
+                                    msg=msg,
+                                    commit=upstream_commit,
+                                    sign=options.sign_tags,
+                                    keyid=options.keyid)
 
                 if not options.native:
                     if options.pristine_tar:
@@ -425,8 +436,7 @@ def main(argv):
                                 "option.")
                     raise GbpError
 
-            tag = repo.version_to_tag(options.packaging_tag, tag_str_fields)
-            msg = "%s release %s" % (options.vendor, ver_str)
+            msg = "%s release %s" % (options.vendor, full_version)
 
             if options.orphan_packaging or not sources:
                 commit = repo.commit_dir(dirs['packaging_base'],
@@ -450,7 +460,7 @@ def main(argv):
                 commit = repo.commit_dir(sources.unpacked,
                                          "Import %s" % msg,
                                          branch,
-                                         other_parents=[src_commit],
+                                         other_parents=[upstream_commit],
                                          author=author,
                                          committer=committer,
                                          create_missing_branch=options.create_missing_branches)
@@ -459,11 +469,13 @@ def main(argv):
                 force_to_branch_head(repo, options.packaging_branch)
 
             # Create packaging tag
-            repo.create_tag(name=tag,
-                            msg=msg,
-                            commit=commit,
-                            sign=options.sign_tags,
-                            keyid=options.keyid)
+            if not options.skip_packaging_tag:
+                tag = repo.version_to_tag(options.packaging_tag, tag_str_fields)
+                repo.create_tag(name=tag,
+                                msg=msg,
+                                commit=commit,
+                                sign=options.sign_tags,
+                                keyid=options.keyid)
 
         force_to_branch_head(repo, options.packaging_branch)
 
@@ -489,7 +501,7 @@ def main(argv):
         del_tmpdir()
 
     if not ret and not skipped:
-        gbp.log.info("Version '%s' imported under '%s'" % (ver_str, repo.path))
+        gbp.log.info("Version '%s' imported under '%s'" % (full_version, repo.path))
     return ret
 
 
