@@ -6,7 +6,10 @@ import unittest
 
 from collections import namedtuple
 
-from gbp.scripts.import_orig import (ImportOrigDebianGitRepository, GbpError, is_30_quilt)
+from gbp.scripts.import_orig import (debian_branch_merge_by_replace,
+                                     GbpError,
+                                     ImportOrigDebianGitRepository,
+                                     is_30_quilt)
 from gbp.scripts.common.import_orig import download_orig
 from . testutils import DebianGitTestRepo
 
@@ -105,3 +108,27 @@ class TestIs30Quilt(DebianGitTestRepo):
     def test_30_quilt_empty_repo(self):
         options = self.Options(debian_branch='master')
         self.assertFalse(is_30_quilt(self.repo, options))
+
+
+class TestMergeModeReplace(DebianGitTestRepo):
+    debian_branch = 'master'
+
+    def setUp(self):
+        DebianGitTestRepo.setUp(self)
+        os.chdir(self.repo.path)
+
+    def testDebianDir(self):
+        """Test that dropping upstream's debian/ workd (#881750)"""
+        self.add_file("debian/control")
+        self.repo.create_branch("upstream")
+        self.repo.set_branch("upstream")
+        self.add_file("upstream_file")
+        self.add_file("debian/changelog")
+        self.repo.set_branch("master")
+        self.repo.create_tag('upstream/1.0', "Upstream 1.0", "upstream")
+        debian_branch_merge_by_replace(self.repo, "upstream/1.0", "1.0", self)
+        self.assertTrue(os.path.exists("debian/control"))
+        # Upstream files must end up on debian branch…
+        self.assertTrue(os.path.exists("upstream_file"))
+        # … but upsream's debian dir must not
+        self.assertFalse(os.path.exists("debian/changelog"))
